table.listing td.designator {
  width: 33%;
}
table.richtext td {
  padding: 0;
}
div.header-title, div.description {
 color: #333;
 background-color: #e5f2ff;
 padding: 1ex;
}
div.header-title {
  border: 1px solid #789;
  border-bottom: none;
  font-size: 115%;
  padding-bottom: 0;
}
div.description {
  border: 1px solid #789;
  border-top: none;
}